==> dyte_client-0.0.8.tar.gz: lib/dyteMeeting.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/services.dart';
import 'dyteParticipant.dart';
import 'dyteSelfParticipant.dart';
import 'package:eventify/eventify.dart';

class DyteMeetingHandler {
  static const MethodChannel _channel = const MethodChannel('dyte_client');
  late EventEmitter events;

  DyteMeetingHandler(){
    this.events = new EventEmitter();
    _channel.setMethodCallHandler(_methodCallHandler);
  }

  Future<void> _methodCallHandler(MethodCall call) async {
    switch (call.method) {
      case 'eventMeetingJoined' :
        events.emit('meetingJoin',null,null);
        print('meetingJoin');
        break;
      case 'eventMeetingEnded' :
        events.emit('meetingEnd',null,null);
        print('meetingEnd');
        break;
      case 'eventMeetingDisconnected' :
        print('meetingDisconnected');
        events.emit('meetingDisconnected',null,null);
        break;
      case 'eventMeetingConnected' :
        print('meetingConnected');
        events.emit('meetingConnected',null,null);
        break;  
      default:
        break;
    }
  }

  static Future<List<DyteParticipant>?> get participants async {
    final List<Map<String, dynamic>> ret =
        await _channel.invokeMethod('getMeetingParticipants');
    List<DyteParticipant> participants = <DyteParticipant>[];
    ret.forEach((p) {
      participants.add(new DyteParticipant(p));
    });
    return participants;
  }

  static Future<DyteSelfParticipant?> get self async {
    final Map<String, dynamic> ret = await _channel.invokeMethod('getSelf');
    return new DyteSelfParticipant(ret);
  }

  void updateUIConfig(Map<String, dynamic> config){
       _channel.invokeMethod('updateUIConfig', {"config": jsonEncode(config)});
  }
}

==> dyte_client-0.0.10.tar.gz: lib/dyteMeeting.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/services.dart';
import 'dyteParticipant.dart';
import 'dyteSelfParticipant.dart';
import 'package:eventify/eventify.dart';

class DyteMeetingHandler {
  static const MethodChannel _channel = const MethodChannel('dyte_client');
  late EventEmitter events;

  DyteMeetingHandler(){
    this.events = new EventEmitter();
    _channel.setMethodCallHandler(_methodCallHandler);
  }

  Future<void> _methodCallHandler(MethodCall call) async {
    switch (call.method) {
      case 'eventMeetingJoined' :
        events.emit('meetingJoin',null,null);
        break;
      case 'eventMeetingEnded' :
        events.emit('meetingEnd',null,null);
        break;
      case 'eventMeetingDisconnected' :
        events.emit('meetingDisconnected',null,null);
        break;
      case 'eventMeetingConnected' :
        events.emit('meetingConnected',null,null);
        break;  
      default:
        break;
    }
  }

  Future<List<DyteParticipant>> get participants async {
    final List<Map<String, dynamic>> ret =
        await _channel.invokeMethod('getMeetingParticipants');
    List<DyteParticipant> participants = <DyteParticipant>[];
    ret.forEach((p) {
      participants.add(new DyteParticipant(p));
    });
    return participants;
  }

  Future<DyteSelfParticipant> get self async {
    final Map<dynamic, dynamic> ret = await _channel.invokeMethod('getSelf');
    return new DyteSelfParticipant(ret);
  }

  void updateUIConfig(Map<String, dynamic> config){
       _channel.invokeMethod('updateUIConfig', {"config": jsonEncode(config)});
  }
}
